@@ -1,5 +1,5 @@
 ;; place-window.jl -- decide where to initially place a window
-;; $Id: placement.jl,v 1.47 2001/02/23 05:48:29 jsh Exp $
+;; $Id: placement.jl,v 1.48 2001/08/24 04:49:33 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -131,19 +131,13 @@ this mode. The single argument is the window to be placed."
 	   (rect-pos (if max-rect
 			 (cons (nth 0 max-rect) (nth 1 max-rect))
 		       (current-head-offset)))
-	   (x (+ (cond
-		  ((< (car dims) (car rect-dims))
-		   (+ (car rect-pos) (random (- (car rect-dims) (car dims)))))
-		  ((< (car dims) (car (current-head-dimensions)))
-		   (random (- (car (current-head-dimensions)) (car dims))))
-		  (t 0))
+	   (x (+ (if (< (car dims) (car rect-dims))
+		     (+ (car rect-pos) (random (- (car rect-dims) (car dims))))
+		   0)
 		 (car (current-head-offset))))
-	   (y (+ (cond
-		  ((< (cdr dims) (cdr rect-dims))
-		   (+ (cdr rect-pos) (random (- (cdr rect-dims) (cdr dims)))))
-		  ((< (cdr dims) (cdr (current-head-dimensions)))
-		   (random (- (cdr (current-head-dimensions)) (cdr dims))))
-		  (t 0))
+	   (y (+ (if (< (cdr dims) (cdr rect-dims))
+		     (+ (cdr rect-pos) (random (- (cdr rect-dims) (cdr dims))))
+		   0)
 		 (cdr (current-head-offset)))))
       (move-window-to w x y)))
 
