@@ -1,5 +1,5 @@
 ;; maximize.jl -- window maximization
-;; $Id: maximize.jl,v 1.58 2001/03/26 19:35:19 jsh Exp $
+;; $Id: maximize.jl,v 1.60 2001/09/03 07:55:10 jsh Exp $
 
 ;; Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -30,6 +30,8 @@
 	    frame-part-movable-p
 	    maximize-truncate-dims
 	    maximize-find-workarea
+	    window-locked-vertically-p
+	    window-locked-horizontally-p
 	    maximize-window
 	    unmaximize-window
 	    maximize-window-vertically
@@ -337,6 +339,14 @@ doesn't overlap any avoided windows, or nil."
 		   #:include-heads (list head))))
       (find-max-rectangle avoided edges head)))
 
+  (define (window-locked-vertically-p w)
+    (and move-lock-when-maximized
+	 (window-maximized-vertically-p w)))
+
+  (define (window-locked-horizontally-p w)
+    (and move-lock-when-maximized
+	 (window-maximized-horizontally-p w)))
+
   (define (frame-part-movable-p w part)
     (if (not move-lock-when-maximized)
 	t
@@ -542,7 +552,14 @@ unmaximized."
       (check-if-maximizable w)))
 
   (add-hook 'property-notify-hook property-notify)
-  (add-hook 'add-window-hook check-if-maximizable)
+
+  (add-hook 'after-initialization-hook
+	    (lambda ()
+	      (map-windows check-if-maximizable)
+	      ;; Don't install this hook until after all windows have
+	      ;; initially been adopted, to avoid maximizing over
+	      ;; avoided windows
+	      (add-hook 'add-window-hook check-if-maximizable)))
 
   (sm-add-saved-properties
    'unmaximized-geometry 'maximized-vertically 'maximized-horizontally)
