@@ -1,5 +1,5 @@
 /* events.c -- Event handling
-   $Id: events.c,v 1.139 2001/06/05 03:54:12 jsh Exp $
+   $Id: events.c,v 1.140 2001/08/25 01:16:42 jsh Exp $
 
    Copyright (C) 1999 John Harper <john@dcs.warwick.ac.uk>
 
@@ -773,6 +773,10 @@ unmap_notify (XEvent *ev)
 
 	focus_off_window (w);
 	XDeleteProperty (dpy, w->id, xa_wm_state);
+
+	/* Changed the window-handling model, don't let windows exist
+	   while they're withdrawn */
+	remove_window (w, Qnil, Qnil);
     }
 }
 
